# SearchSource: ABI/INFORM ProQuest

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[ABI/INFORM ProQuest](https://about.proquest.com/en/products-services/abi_inform_complete/)

## Add the search source

Download search results and store in `data/search/` directory. No API-access available.

## Links
